==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação do vídeo está em curso. Fechar a janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Trocar de câmaras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do ficheiro</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Disparar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo contínuo</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atraso do temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>A Câmara é um utilitário de captura de imagem e vídeo que usa a câmara do PC ou webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Ficheiro não guardado</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Guardar para:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Definições de resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolução:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efeitos sonoros</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modo de espelho</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Parar de gravar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Parar de tirar fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu de contexto</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Tirar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Parar de tirar fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vívido</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Quente</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Frio</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Cinema</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>P&amp;B</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Atrasar a captura</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposição</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Parar de gravar</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação do vídeo está em curso. Fechar a janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Trocar de câmaras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do ficheiro</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Disparar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo contínuo</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atraso do temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>A Câmara é um utilitário de captura de imagem e vídeo que utiliza a câmara do PC ou webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Ficheiro não guardado</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Guardar para:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Definições de resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolução:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efeitos sonoros</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modo de espelho</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Linhas de grelha</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Linhas 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Linhas 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Parar de gravar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Parar de tirar fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu de contexto</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Tirar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Parar de tirar fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vívido</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Quente</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Frio</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Cinema</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>P&amp;B</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Atrasar a captura</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposição</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Parar de gravar</translation>
    </message>
</context>
</TS>
